diff --git a/Documentation/NXGraphicsSubsystem.html b/Documentation/NXGraphicsSubsystem.html index a9723453ded..273a8fcc836 100644 --- a/Documentation/NXGraphicsSubsystem.html +++ b/Documentation/NXGraphicsSubsystem.html @@ -93,7 +93,7 @@ 2.3.3 Starting the NX Server
nx_start()nxmu_start()boardctl()@@ -937,13 +937,13 @@ struct nx_callback_s
- The NX server may be started in your board startup logic by simply calling the function nx_start().
+ The NX server may be started in your board startup logic by simply calling the function nxmu_start().
The board startup logic usually resides the the configs/board/src directory.
The boar board startup logic can run automatically during the early system if CONFIG_BOARD_INITIALIZE is defined in the configuration.
Or, the board startup logic can execute under control of the application by calling the boardctl(BOARDIOC_INIT, arg) OS interface.
- The board initialization logic will run in either case and the simple call to nx_start() will start the NX server.
+ The board initialization logic will run in either case and the simple call to nxmu_start() will start the NX server.
nx_start()nxmu_start()Function Prototype:
#include <nuttx/nx/nx.h> -int nx_start(void); +int nxmu_start(void);
Description:
- nx_start() provides a wrapper function to simplify and standardize the starting of the NX server.
+ nxmu_start() provides a wrapper function to simplify and standardize the starting of the NX server.
Input Parameters: @@ -996,7 +996,7 @@ int nx_start(void); In it is especially useful for setting up board operational and test configurations.
- When called with the cmd of BOARDIOC_NX_START, then the boardctl() will call nx_start indirectly on behalf of the appication.
+ When called with the cmd of BOARDIOC_NX_START, then the boardctl() will call nxmu_start indirectly on behalf of the appication.
In this case the arg parameter is ignored.
diff --git a/graphics/Kconfig b/graphics/Kconfig
index c839aa89240..5f3094678e6 100644
--- a/graphics/Kconfig
+++ b/graphics/Kconfig
@@ -394,10 +394,10 @@ config NXSTART_EXTERNINIT
select LCD_EXTERNINIT if LCD && LCD_FRAMEBUFFER && NX_LCDDRIVER
---help---
Define to support external display initialization by platform-
- specific code. This this option is defined, then nx_start() will
- call board_graphics_setup(CONFIG_NXSTART_DEVNO) to initialize the
- graphics device. This option is necessary if display is used that
- cannot be initialized using the standard LCD or framebuffer
+ specific code. This this option is defined, then nxmu_start()
+ will call board_graphics_setup(CONFIG_NXSTART_DEVNO) to initialize
+ the graphics device. This option is necessary if display is used
+ that cannot be initialized using the standard LCD or framebuffer
interfaces.
config NXSTART_SERVERPRIO
diff --git a/graphics/nxmu/Make.defs b/graphics/nxmu/Make.defs
index b872b4cb3b0..21feb883bb1 100644
--- a/graphics/nxmu/Make.defs
+++ b/graphics/nxmu/Make.defs
@@ -36,7 +36,7 @@
CSRCS += nxmu_kbdin.c nxmu_mouse.c nxmu_openwindow.c nxmu_redrawreq.c
CSRCS += nxmu_releasebkgd.c nxmu_requestbkgd.c nxmu_reportposition.c
CSRCS += nxmu_sendclient.c nxmu_sendclientwindow.c nxmu_server.c
-CSRCS += nx_start.c
+CSRCS += nxmu_start.c
DEPPATH += --dep-path nxmu
CFLAGS += ${shell $(INCDIR) $(INCDIROPT) "$(CC)" $(TOPDIR)/graphics/nxmu}
diff --git a/graphics/nxmu/nx_start.c b/graphics/nxmu/nxmu_start.c
similarity index 94%
rename from graphics/nxmu/nx_start.c
rename to graphics/nxmu/nxmu_start.c
index 757b418d7e9..c76b0eb39d7 100644
--- a/graphics/nxmu/nx_start.c
+++ b/graphics/nxmu/nxmu_start.c
@@ -1,7 +1,7 @@
/****************************************************************************
- * graphics/nxmu/nx_start.c
+ * graphics/nxmu/nxmu_start.c
*
- * Copyright (C) 2013, 2016-2017 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2013, 2016-2017, 2019 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt
diff --git a/configs/boardctl.c b/configs/boardctl.c
index cca53db3c91..b335e76c507 100644
--- a/configs/boardctl.c
+++ b/configs/boardctl.c
@@ -407,12 +407,12 @@ int boardctl(unsigned int cmd, uintptr_t arg)
* DESCRIPTION: Start the NX servier
* ARG: None
* CONFIGURATION: CONFIG_NX
* DEPENDENCIES: Base graphics logic provides nx_start()
*/
case BOARDIOC_NX_START:
{
- ret = nx_start();
+ ret = nxmu_start();
}
break;
#endif
@@ -407,12 +407,12 @@ int boardctl(unsigned int cmd, uintptr_t arg)
* ARG: None
* CONFIGURATION: CONFIG_NX
- * DEPENDENCIES: Base graphics logic provides nx_start()
+ * DEPENDENCIES: Base graphics logic provides nxmu_start()
*/
case BOARDIOC_NX_START: